@@ -2,7 +2,7 @@ from typing import Any
 
 import fastapi.security
 
-from project.api.const import APIErrorCodes
+from project.api.api_error_codes import APIErrorCodes
 from project.api.schema.out.common.error import ErrorCommonSO
 
 
