@@ -129,6 +129,12 @@ class Settings(SimpleSettings):
 
     api_openapi_url: str = "/secret/openapi"
 
+    api_uvicorn_timeout_keep_alive: int = 3
+
+    api_uvicorn_limit_concurrency: int = 1000
+
+    api_uvicorn_backlog: int = 2048
+
     sqladmin_secret_key: str | None = "85a9583cb91c4de7a78d7eb1e5306a04418c9c43014c447ea8ec8dd5deb4cf71"
 
     sqladmin_authorize_keys: list[str] | None = ["1"]
